# Mapping SAP Signavio Processes to Fact Sheets
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/mapping-sap-signavio-processes-to-fact-sheets#introduction)
  * [Mapping Processes](https://help.sap.com/docs/leanix/ea/mapping-sap-signavio-processes-to-fact-sheets#mapping-processes)
  * [Choosing Sync Mode](https://help.sap.com/docs/leanix/ea/mapping-sap-signavio-processes-to-fact-sheets#choosing-sync-mode)
  * [Configuring the Process Synchronization Hierarchy](https://help.sap.com/docs/leanix/ea/mapping-sap-signavio-processes-to-fact-sheets#configuring-the-process-synchronization-hierarchy)
  * [Choosing Process Hierarchy Relation](https://help.sap.com/docs/leanix/ea/mapping-sap-signavio-processes-to-fact-sheets#choosing-process-hierarchy-relation)
  * [Configuring Interval-Based Synchronization](https://help.sap.com/docs/leanix/ea/mapping-sap-signavio-processes-to-fact-sheets#configuring-interval-based-synchronization)
  * [Activating and Deactivating Mapped Processes](https://help.sap.com/docs/leanix/ea/mapping-sap-signavio-processes-to-fact-sheets#activating-and-deactivating-mapped-processes)
  * [Mapping Process Attributes to Fact Sheet Attributes](https://help.sap.com/docs/leanix/ea/mapping-sap-signavio-processes-to-fact-sheets#mapping-process-attributes-to-fact-sheet-attributes)


View all
Learn how to map and sync processes from SAP Signavio to SAP LeanIX. Configure synchronization modes, set process hierarchy, and manage process attributes with field and value mapping.
